@@ -281,6 +281,7 @@ class DBTables(enum.Enum):
     INPUTS = "inputs"
     PORTFOLIO = "portfolio"
     ORDERS = "all_orders"
+    HISTORICAL_ORDERS_UPDATES = "order_updates"
     TRADES = "all_trades"
     TRANSACTIONS = "all_transactions"
     CANDLES = "candles"
@@ -410,6 +411,7 @@ class UserInputTentacleTypes(enum.Enum):
     TRADING_MODE = "trading_mode"
     EVALUATOR = "evaluator"
     EXCHANGE = "exchange"
+    WEB_PLUGIN = "web_plugin"
     AUTOMATION = "automation"
     UNDEFINED = "undefined"
 
