@@ -14,7 +14,6 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-
 import octobot_commons
 import octobot_commons.enums as enums
 import octobot_commons.constants as constants
@@ -60,8 +59,10 @@ def open_order_pretty_printer(exchange_name, dict_order, markdown=False) -> str:
 
         return (
             f"{code}{order_type.name.replace('_', ' ')}{code}: {code}"
-            f"{get_min_string_from_number(quantity)} {quantity_currency}{code} at {code}"
-            f"{get_min_string_from_number(price)} {market}{code} on {exchange_name.capitalize()}"
+            f"{get_min_string_from_number(quantity)} "
+            f"{quantity_currency}{code} at {code}"
+            f"{get_min_string_from_number(price)} {market}{code} "
+            f"on {exchange_name.capitalize()}"
         )
     except ImportError:
         LOGGER.error(
@@ -95,7 +96,8 @@ def trade_pretty_printer(exchange_name, trade, markdown=False) -> str:
         )
         return (
             f"{code}{trade_type.name.replace('_', ' ')}{code}: {code}"
-            f"{get_min_string_from_number(trade.executed_quantity)} {trade.quantity_currency}{code} at {code}"
+            f"{get_min_string_from_number(trade.executed_quantity)} "
+            f"{trade.quantity_currency}{code} at {code}"
             f"{get_min_string_from_number(trade.executed_price)} {trade.market}{code} "
             f"{exchange_name.capitalize()} "
             f"{trade_executed_time_str} "
@@ -130,31 +132,101 @@ def cryptocurrency_alert(result, final_eval) -> (str, str):
     return "", ""
 
 
+def _get_row_pretty_portfolio_row(holdings, currency, ref_market, ref_market_value):
+    """
+    :return: the portfolio row adapted for a raw format
+    """
+    str_holdings = get_min_string_from_number(holdings)
+    if ref_market:
+        return f"{str_holdings} {currency}{get_min_string_from_number(ref_market_value)} {ref_market}"
+    return f"{str_holdings} {currency}"
+
+
+def _get_markdown_pretty_portfolio_row(
+    holdings, currency, ref_market, ref_market_value
+):
+    """
+    :return: the portfolio row adapted for a markdown format
+    """
+    str_currency = "{:<4}".format(currency)
+    str_holdings = "{:<12}".format(get_min_string_from_number(holdings, max_digits=6))
+    str_ref_market_value = "{:<12}".format("")
+    if ref_market:
+        str_ref_market_value = "{:<12}".format(
+            get_min_string_from_number(ref_market_value) if ref_market_value else ""
+        )
+    return f"{str_currency} {str_holdings} {str_ref_market_value}"
+
+
 def global_portfolio_pretty_print(
-    global_portfolio, separator="\n", markdown=False
+    global_portfolio,
+    currency_values=None,
+    ref_market_name=None,
+    separator="\n",
+    markdown=False,
 ) -> str:
     """
     Global portfolio pretty printer
     :param global_portfolio: the global portfolio
+    :param currency_values: dict of current currency values {"BTC": 20000, "ETH": 1000 }
+    :param ref_market_name: current ref market "USD"
     :param separator: the printer separator
     :param markdown: if printer use markdown
     :return: the global portfolio pretty printed
     """
-    result = []
-    for currency, asset_dict in global_portfolio.items():
+    results = []
+    currency = "currency"
+    holdings = "holdings"
+    value = "value"
+    for asset, asset_dict in global_portfolio.items():
         if asset_dict[constants.PORTFOLIO_TOTAL] > 0:
             # fill lines with empty spaces if necessary
-            total = get_min_string_from_number(asset_dict[constants.PORTFOLIO_TOTAL])
-            if markdown:
-                total = "{:<10}".format(total)
-            available = f"({get_min_string_from_number(asset_dict[constants.PORTFOLIO_AVAILABLE])})"
-            if markdown:
-                available = "{:<12}".format(available)
-
-            holding_str = f"{total} {available} {currency}"
-            result.append(holding_str)
-
-    return separator.join(result)
+            holdings_value = 0
+            if currency_values and ref_market_name:
+                if ref_market_name == asset:
+                    holdings_value = asset_dict[constants.PORTFOLIO_TOTAL]
+                else:
+                    try:
+                        holdings_value = (
+                            currency_values[asset]
+                            * asset_dict[constants.PORTFOLIO_TOTAL]
+                        )
+                    except KeyError:
+                        # no currency value
+                        pass
+            results.append(
+                {
+                    currency: asset,
+                    holdings: asset_dict[constants.PORTFOLIO_TOTAL],
+                    value: holdings_value,
+                }
+            )
+    # force "value" str for cythonization
+    results.sort(key=lambda r: r["value"], reverse=True)
+    if markdown:
+        header = (
+            f"{'{:<4}'.format('')} "
+            f"{'  {:<9}'.format('Holdings')}  "
+            f"{'    {:<7}'.format(ref_market_name or '')}"
+        )
+        header_separator = f"{'-' * 4}|{'-' * 12}|{'-' * 12}"
+        content = separator.join(
+            [
+                _get_markdown_pretty_portfolio_row(
+                    result[holdings], result[currency], ref_market_name, result[value]
+                )
+                for result in results
+            ]
+        )
+        return f"{header}\n{header_separator}\n{content}"
+    return separator.join(
+        [
+            _get_row_pretty_portfolio_row(
+                result[holdings], result[currency], ref_market_name, result[value]
+            )
+            for result in results
+        ]
+    )
 
 
 def portfolio_profitability_pretty_print(
