@@ -19,8 +19,8 @@ import copy
 
 
 import octobot_commons.enums as commons_enums
+import octobot_commons.configuration.user_inputs as user_inputs
 import octobot_commons.configuration as configuration
-import octobot_commons.databases as databases
 
 
 class AbstractTentacle:
@@ -29,12 +29,23 @@ class AbstractTentacle:
     """
 
     __metaclass__ = abc.ABCMeta
-    ALLOW_SUPER_CLASS_CONFIG = False
-    USER_INPUT_TENTACLE_TYPE = commons_enums.UserInputTentacleTypes.UNDEFINED
+
+    ALLOW_SUPER_CLASS_CONFIG = (
+        False  # when True, the given tentacle can read its parent class configuration
+    )
+    USER_INPUT_TENTACLE_TYPE = (
+        commons_enums.UserInputTentacleTypes.UNDEFINED
+    )  # tentacle type, saved in user inputs
+    HISTORIZE_USER_INPUT_CONFIG = (
+        False  # when True, user input values can be saved and read from the run data db
+    )
+    CLASS_UI = user_inputs.UserInputFactory(
+        commons_enums.UserInputTentacleTypes.UNDEFINED
+    )  # class-level user input factory. Used when initializing user inputs with classmethods
 
     def __init__(self):
         self.logger = None
-        self.UI: configuration.UserInputFactory = configuration.UserInputFactory(
+        self.UI: user_inputs.UserInputFactory = user_inputs.UserInputFactory(
             self.USER_INPUT_TENTACLE_TYPE
         )
         self.UI.set_tentacle_class(self.__class__).set_tentacle_config_proxy(
@@ -61,6 +72,13 @@ class AbstractTentacle:
                 subclasses_list += subclass.get_all_subclasses()
         return subclasses_list
 
+    @classmethod
+    def is_configurable(cls):
+        """
+        Override if the tentacle is allowed to be configured
+        """
+        return True
+
     @classmethod
     def get_user_commands(cls) -> dict:
         """
@@ -71,6 +89,7 @@ class AbstractTentacle:
 
     def get_local_config(self):
         """
+        Implementation required if cls.HISTORIZE_USER_INPUT_CONFIG is True
         :return: the config of the tentacle
         """
         raise NotImplementedError
@@ -78,6 +97,7 @@ class AbstractTentacle:
     @classmethod
     def create_local_instance(cls, config, tentacles_setup_config, tentacle_config):
         """
+        Implementation required if cls.HISTORIZE_USER_INPUT_CONFIG is True
         :param config: the global configuration to give to the tentacle
         :param tentacles_setup_config: the global tentacles setup configuration to give to the tentacle
         :param tentacle_config: the tentacle configuration to give to the tentacle
@@ -87,27 +107,40 @@ class AbstractTentacle:
 
     def init_user_inputs(self, inputs: dict) -> None:
         """
+        instance method API for user inputs. Used by load_and_save_user_inputs
+        Override if this tentacle has user inputs that should be initialized on a specific instance
         Called right before starting the tentacle, should define all the tentacle's user inputs unless
         those are defined somewhere else.
         """
 
-    async def load_and_save_user_inputs(self, bot_id: str):
+    @classmethod
+    def init_user_inputs_from_class(cls, inputs: dict) -> None:
         """
-        Initialize and save the user inputs of the tentacle
+        classmethod API for user inputs. Used by init_user_inputs_from_class
+        Override if this tentacle has user inputs that can be initialized on a class level
+        Called by load_user_inputs_from_class, should define all the tentacle user inputs.
         """
-        try:
-            inputs = {}
-            self.init_user_inputs(inputs)
-            if databases.RunDatabasesProvider.instance().is_storage_enabled(bot_id):
-                run_db = databases.RunDatabasesProvider.instance().get_run_db(bot_id)
-                await configuration.clear_user_inputs(run_db, self.get_name())
-                for user_input in inputs.values():
-                    await configuration.save_user_input(user_input, run_db)
-                await run_db.flush()
-        except Exception as err:
-            self.logger.exception(
-                err, True, f"Error when initializing user inputs: {err}"
-            )
+
+    async def load_and_save_user_inputs(self, bot_id: str) -> dict:
+        """
+        instance method API for user inputs
+        Initialize and save the tentacle user inputs in run data
+        :return: the filled user input configuration
+        """
+        return await configuration.load_and_save_user_inputs(self, bot_id)
+
+    @classmethod
+    def load_user_inputs_from_class(
+        cls, tentacles_setup_config, tentacle_config
+    ) -> dict:
+        """
+        classmethod API for user inputs
+        Initialize the tentacle user inputs
+        Called by get_raw_config_and_user_inputs
+        """
+        return configuration.load_user_inputs_from_class(
+            cls, tentacles_setup_config, tentacle_config
+        )
 
     @classmethod
     async def get_raw_config_and_user_inputs(
@@ -116,25 +149,10 @@ class AbstractTentacle:
         """
         :return: the tentacle configuration and its list of user inputs
         """
-        try:
-            import octobot_tentacles_manager.api as api
-
-            specific_config = api.get_tentacle_config(tentacles_setup_config, cls)
-        except ImportError as err:
-            raise ImportError("octobot_tentacles_manager is required") from err
-        if saved_user_inputs := await configuration.get_user_inputs(
-            databases.RunDatabasesProvider.instance().get_run_db(bot_id),
-            cls.get_name(),
-        ):
-            # user inputs have been saved in run database, use those as they might contain additional
-            # (nested) user inputs
-            return specific_config, saved_user_inputs
-        # use user inputs from init_user_inputs
-        tentacle_instance = cls.create_local_instance(
-            config, tentacles_setup_config, specific_config
-        )
-        user_inputs = {}
-        tentacle_instance.init_user_inputs(user_inputs)
-        return specific_config, list(
-            user_input.to_dict() for user_input in user_inputs.values()
+        if not cls.HISTORIZE_USER_INPUT_CONFIG:
+            return configuration.get_raw_config_and_user_inputs_from_class(
+                cls, tentacles_setup_config
+            )
+        return await configuration.get_raw_config_and_user_inputs(
+            cls, config, tentacles_setup_config, bot_id
         )
